#
# spec file for package python-hankel
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define modname hankel
Name:           python-hankel
Version:        1.2.2
Release:        2.3
Summary:        Hankel Transformations using method of Ogata 2005
License:        MIT
URL:            https://github.com/steven-murray/hankel
Source:         https://files.pythonhosted.org/packages/source/h/%{modname}/%{modname}-%{version}.tar.gz
# https://github.com/steven-murray/hankel/commit/3307d7527325dc80ac441d845982f93fd84d5311
Patch0:         fix-get_h-test.patch
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-mpmath >= 1.0.0
Requires:       python-numpy >= 1.9.3
Requires:       python-scipy >= 0.16.1
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module mpmath >= 1.0.0}
BuildRequires:  %{python_module numpy >= 1.9.3}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module scipy >= 0.16.1}
# /SECTION
%python_subpackages

%description
Hankel is a Python library to perform simple and accurate Hankel
transformations using the method of Ogata 2005.

%prep
%autosetup -p1 -n hankel-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# TESTS TAKE TOO LONG ON i586 LEADING TO OBS WORKER TIMING OUT
%if "%{_lib}" != "lib"
%check
%pytest
%endif

%files %{python_files}
%doc README.rst CHANGELOG.rst
%license LICENSE.rst
%{python_sitelib}/%{modname}/
%{python_sitelib}/%{modname}-%{version}-py%{python_version}.egg-info/

%changelog
* Thu Nov 14 2024 Nico Krapp <nico.krapp@suse.com>
- Add fix-get_h-test.patch to fix numpy ValueError in tests
  * from: https://github.com/steven-murray/hankel/commit/3307d7527325dc80ac441d845982f93fd84d5311
* Thu Sep 14 2023 Markéta Machová <mmachova@suse.com>
- Update to 1.2.2
  * Fixed installation (eg. #101)
- Drop fix-requirements.patch, no longer needed
* Wed Feb  8 2023 Steve Kowalik <steven.kowalik@suse.com>
- Add patch fix-requirements.patch:
  * Stop specifying an invalid Sphinx version.
* Sun May  1 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.2.1:
  * The ``.G()`` has been removed as planned.
- Changes from version 1.2.0:
  * Switched to using ``setup.cfg`` instead of ``setup.py`` and
    various other tooling updates.
* Sat Feb 13 2021 Benjamin Greiner <code@bnavigator.de>
- NEP29: TW does not have python36-scipy anymore
  skip python36 build
* Mon Sep 14 2020 Atri Bhattacharya <badshah400@gmail.com>
- Switch to using PyPI source tarball to prevent version
  determination errors from setuptools.
- Make file list more specific, particularly to the versioning of
  the egg-info dir.
* Wed Jun 10 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.1.0:
  * Adds ability to transform complex-valued functions.
- Use %%{name}-%%{version} naming scheme for source tarball.
- Update package versions in Requires and BuildRequires in keeping
  with upstream.
- Don't run tests for i586 arch where they take too long leading to
  the obs worker shutting down assuming a stuck job.
* Thu Apr 23 2020 Tomáš Chvátal <tchvatal@suse.com>
- Drop py2 deps as package is py3 only
* Wed Apr  8 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.0.2
  * Limit calculation for k=0 provided (resulted in nan before)
  * Alternative hankel kernel now selectable: sqrt(x) * J(nu, x)
  * Caching of series factors for faster calculations
  * Various infrastructure upgrades (setuptools_scm, pre-commit, black)
  * Saver calculation of xrange_approx
  * Methods ``G`` and ``deltaG`` now named ``final_term_amplitude`` and ``slope_of_last_term``.
  * Upstream apparently dropped Python 2.
* Thu Sep 12 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.9:
  * Fixed SymmetricFourierTransform default N to be dynamic, like HankelTransform.
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.3.8:
  * Swapped to pytest from nose for all testing
  * Removed warnings of overflow for cosh and sinh functions
  * Improved documentation in many areas.
  * Swapped out default 3.2/h for pi/h, which sounds way cooler :-)
  * Fixed an error in tests such that the wrong analytic function was being tested.
  * Removed a check for deltaG in get_h, which sometimes fails spectacularly.
  * Fixed issue in Py3 in which dim=2 would not run the fast function (thanks @MuellerSeb)
  * Added support for transforms with nu=-0.5 (thanks @MuellerSeb)
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sat Mar 24 2018 badshah400@gmail.com
- Initial package.
